@@ -10,7 +10,7 @@ use Carp;
 use Lingua::Sentence;
 
 use vars qw($VERSION);
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 sub new {
   my $class = shift;
@@ -229,6 +229,10 @@ Fixed a bug for n-grams n-skipgrams with n > 2
 
 Fixed test
 
+=item 0.06
+
+Fixed meta.yml
+
 =back
 
 =head1 AUTHOR
